Value

pub enum Value {
Show 16 variants Exception(ResponseException), Echo(ResponseEcho), Flush(ResponseFlush), Info(ResponseInfo), InitChain(ResponseInitChain), Query(ResponseQuery), CheckTx(ResponseCheckTx), ListSnapshots(ResponseListSnapshots), OfferSnapshot(ResponseOfferSnapshot), LoadSnapshotChunk(ResponseLoadSnapshotChunk), ApplySnapshotChunk(ResponseApplySnapshotChunk), PrepareProposal(ResponsePrepareProposal), ProcessProposal(ResponseProcessProposal), ExtendVote(ResponseExtendVote), VerifyVoteExtension(ResponseVerifyVoteExtension), FinalizeBlock(ResponseFinalizeBlock),
}

Variants

Implementations

Source

impl Value

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<Value>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.